Company Information:

| Home | EDGAR Search Home | Latest Filings | Previous Page |

# No matching Ticker Symbol.

EDGAR Search Results
EDGAR Search Results
Mailing Address ONE APPLE PARK WAY CUPERTINO CA 95014
Business Address ONE APPLE PARK WAY CUPERTINO CA 95014 (408) 996-1010
Apple Inc. CIK#: 0000320193 (see all company filings)

SIC: 3571 - ELECTRONIC COMPUTERS
State location: CA | State of Inc.: CA | Fiscal Year End: 0926
formerly: APPLE COMPUTER INC (filings through 2007-01-04)
formerly: APPLE COMPUTER INC/ FA (filings through 1997-07-28)
formerly: APPLE INC (filings through 2019-08-05)
(Office of Technology)
Get insider transactions for this issuer.

Filter Results: | Filing Type: | Prior to: (YYYYMMDD) | Ownership? include exclude only | Limit Results Per Page |

Items 1 - 28 RSS Feed

Filings | Format | Description | Filing Date | File/Film Number
--- | --- | --- | --- | ---
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-19-000119 (34 Act) Size: 12 MB | 2019-10-31 | 001-36743 191181423
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-18-000145 (34 Act) Size: 12 MB | 2018-11-05 | 001-36743 181158788
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-17-000070 (34 Act) Size: 14 MB | 2017-11-03 | 001-36743 171174673
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001628280-16-020309 (34 Act) Size: 13 MB | 2016-10-26 | 001-36743 161953070
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-15-356351 (34 Act) Size: 9 MB | 2015-10-28 | 001-36743 151180619
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-14-383437 (34 Act) Size: 12 MB | 2014-10-27 | 000-10030 141175110
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-13-416534 (34 Act) Size: 11 MB | 2013-10-30 | 000-10030 131177575
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-12-444068 (34 Act) Size: 9 MB | 2012-10-31 | 000-10030 121171452
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-11-282113 (34 Act) Size: 9 MB | 2011-10-26 | 000-10030 111159350
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-10-238044 (34 Act) Size: 13 MB | 2010-10-27 | 000-10030 101145250
10-K/A | Documents Interactive Data | [Amend] Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-10-012091 (34 Act) Size: 5 MB | 2010-01-25 | 000-10030 10545024
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-09-214859 (34 Act) Size: 3 MB | 2009-10-27 | 000-10030 091139493
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-08-224958 (34 Act) Size: 1 MB | 2008-11-05 | 000-10030 081162315
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-07-009340 (34 Act) Size: 1 MB | 2007-11-15 | 000-10030 071250316
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001104659-06-084288 (34 Act) Size: 4 MB | 2006-12-29 | 000-10030 061304002
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001104659-05-058421 (34 Act) Size: 3 MB | 2005-12-01 | 000-10030 051235812
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-04-035975 (34 Act) Size: 966 KB | 2004-12-03 | 000-10030 041181605
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-03-041604 Size: 2 MB | 2003-12-19 | 000-10030 031066037
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-02-007674 Size: 895 KB | 2002-12-19 | 000-10030 02863602
10-K405 | Documents | Annual report [Sections 13 and 15(d), S-K Item 405] Acc-no: 0000912057-01-544436 Size: 791 KB | 2001-12-21 | 000-10030 1821603
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000912057-00-053623 Size: 310 KB | 2000-12-14 | 000-10030 789406
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000912057-99-010244 Size: 502 KB | 1999-12-22 | 000-10030 99778628
10-K405 | Documents | Annual report [Sections 13 and 15(d), S-K Item 405] Acc-no: 0001047469-98-044981 Size: 341 KB | 1998-12-23 | 000-10030 98774868
10-K/A | Documents | [Amend] Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-98-001822 Size: 51 KB | 1998-01-23 | 000-10030 98511354
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-97-006960 Size: 639 KB | 1997-12-05 | 000-10030 97733413
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-96-000023 Size: 271 KB | 1996-12-19 | 000-10030 96683426
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-95-000016 Size: 232 KB | 1995-12-19 | 000-10030 95602696
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-94-000016 Size: 240 KB | 1994-12-13 | 000-10030 94564347

EDGAR Search Results
EDGAR Search Results
Mailing Address ONE APPLE PARK WAY CUPERTINO CA 95014
Business Address ONE APPLE PARK WAY CUPERTINO CA 95014 (408) 996-1010
Apple Inc. CIK#: 0000320193 (see all company filings)

SIC: 3571 - ELECTRONIC COMPUTERS
State location: CA | State of Inc.: CA | Fiscal Year End: 0926
formerly: APPLE COMPUTER INC (filings through 2007-01-04)
formerly: APPLE COMPUTER INC/ FA (filings through 1997-07-28)
formerly: APPLE INC (filings through 2019-08-05)
(Office of Technology)
Get insider transactions for this issuer.

Filter Results: | Filing Type: | Prior to: (YYYYMMDD) | Ownership? include exclude only | Limit Results Per Page |

Items 1 - 40 RSS Feed |

Filings | Format | Description | Filing Date | File/Film Number
--- | --- | --- | --- | ---
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-20-000010 (34 Act) Size: 9 MB | 2020-01-29 | 001-36743 20555794
8-K | Documents Interactive Data | Current report, items 2.02 and 9.01 Acc-no: 0000320193-20-000008 (34 Act) Size: 531 KB | 2020-01-28 | 001-36743 20554729
PX14A6G | Documents | Notice of exempt solicitation submitted by non-management Acc-no: 0001214659-20-000610 (34 Act) Size: 87 KB | 2020-01-27 | 001-36743 20548807
PX14A6G | Documents | Notice of exempt solicitation submitted by non-management Acc-no: 0001387131-20-000386 (34 Act) Size: 45 KB | 2020-01-22 | 001-36743 20537776
DEFA14A | Documents | Additional definitive proxy soliciting materials and Rule 14(a)(12) material Acc-no: 0001193125-20-001452 (34 Act) Size: 715 KB | 2020-01-03 | 001-36743 20506033
DEF 14A | Documents | Other definitive proxy statements Acc-no: 0001193125-20-001450 (34 Act) Size: 4 MB | 2020-01-03 | 001-36743 20505940
CERT | Documents | Acc-no: 0001354457-19-000604 (34 Act) Size: 202 KB | 2019-11-15 | 001-36743 191222519
8-A12B | Documents | Registration of securities [Section 12(b)] Acc-no: 0001193125-19-292825 (34 Act) Size: 19 KB | 2019-11-15 | 001-36743 191222426
8-K | Documents Interactive Data | Current report, items 8.01 and 9.01 Acc-no: 0001193125-19-292676 (34 Act) Size: 645 KB | 2019-11-15 | 001-36743 191222355
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-288412 (33 Act) Size: 439 KB | 2019-11-08 | 333-228159 191204489
FWP | Documents | Filing under Securities Act Rules 163/433 of free writing prospectuses Acc-no: 0001193125-19-287351 (34 Act) Size: 35 KB | 2019-11-07 | 333-228159 191200817
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-286514 (33 Act) Size: 433 KB | 2019-11-07 | 333-228159 191197982
S-8 POS | Documents | Securities to be offered to employees in employee benefit plans, post-effective amendments Acc-no: 0001193125-19-280516 (33 Act) Size: 74 KB | 2019-10-31 | 333-165214 191184102
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-19-000119 (34 Act) Size: 12 MB | 2019-10-31 | 001-36743 191181423
8-K | Documents Interactive Data | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000117 (34 Act) Size: 576 KB | 2019-10-30 | 001-36743 191180631
8-K | Documents Interactive Data | Current report, item 5.02 Acc-no: 0000320193-19-000093 (34 Act) Size: 295 KB | 2019-09-13 | 001-36743 191093220
8-K | Documents Interactive Data | Current report, items 8.01 and 9.01 Acc-no: 0001193125-19-242975 (34 Act) Size: 777 KB | 2019-09-11 | 001-36743 191088535
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-238922 (33 Act) Size: 390 KB | 2019-09-05 | 333-228159 191077641
FWP | Documents | Filing under Securities Act Rules 163/433 of free writing prospectuses Acc-no: 0001193125-19-237993 (34 Act) Size: 82 KB | 2019-09-05 | 333-228159 191075999
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-237090 (33 Act) Size: 375 KB | 2019-09-04 | 333-228159 191073320
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-19-000076 (34 Act) Size: 10 MB | 2019-07-31 | 001-36743 19989192
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000073 (34 Act) Size: 303 KB | 2019-07-30 | 001-36743 19985848
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-19-000066 (34 Act) Size: 10 MB | 2019-05-01 | 001-36743 19788072
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000063 (34 Act) Size: 289 KB | 2019-04-30 | 001-36743 19782221
CERT | Documents | Acc-no: 0001354457-19-000130 (34 Act) Size: 154 KB | 2019-03-14 | 001-36743 19681650
25 | Documents | Notification of the removal from listing and registration of matured, redeemed or retired securities Acc-no: 0001193125-19-074874 (34 Act) Size: 13 KB | 2019-03-14 | 001-36743 19681578
8-A12B | Documents | Registration of securities [Section 12(b)] Acc-no: 0001193125-19-074868 (34 Act) Size: 22 KB | 2019-03-14 | 001-36743 19681549
8-K | Documents | Current report, item 5.07 Acc-no: 0000320193-19-000032 (34 Act) Size: 66 KB | 2019-03-04 | 001-36743 19654221
SD | Documents | Acc-no: 0001193125-19-041571 (34 Act) Size: 585 KB | 2019-02-15 | 001-36743 19609779
SC 13G | Documents | Statement of acquisition of beneficial ownership by individuals Acc-no: 0001193125-19-041014 (34 Act) Size: 702 KB | 2019-02-14 | 005-33632 19607502
SC 13G/A | Documents | [Amend] Statement of acquisition of beneficial ownership by individuals Acc-no: 0000932471-19-004418 (34 Act) Size: 34 KB | 2019-02-11 | 005-33632 19582280
8-K | Documents | Current report, item 5.02 Acc-no: 0000320193-19-000026 (34 Act) Size: 29 KB | 2019-02-06 | 001-36743 19569878
PX14A6G | Documents | Notice of exempt solicitation submitted by non-management Acc-no: 0001214659-19-000797 (34 Act) Size: 10 KB | 2019-02-05 | 001-36743 19566496
SC 13G/A | Documents | [Amend] Statement of acquisition of beneficial ownership by individuals Acc-no: 0000215457-19-003343 (34 Act) Size: 13 KB | 2019-02-04 | 005-33632 19562213
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-19-000010 (34 Act) Size: 8 MB | 2019-01-30 | 001-36743 19552275
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000007 (34 Act) Size: 228 KB | 2019-01-29 | 001-36743 19549017
DEFA14A | Documents | Additional definitive proxy soliciting materials and Rule 14(a)(12) material Acc-no: 0001193125-19-004678 (34 Act) Size: 470 KB | 2019-01-08 | 001-36743 19516394
DEF 14A | Documents | Other definitive proxy statements Acc-no: 0001193125-19-004664 (34 Act) Size: 5 MB | 2019-01-08 | 001-36743 19516351
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000002 (34 Act) Size: 66 KB | 2019-01-02 | 001-36743 19502044
S-3ASR | Documents | Automatic shelf registration statement of securities of well-known seasoned issuers Acc-no: 0001193125-18-317844 (33 Act) Size: 768 KB | 2018-11-05 | 333-228159 181158810

EDGAR Filing Documents for 0000320193-19-000119
Search the Next-Generation EDGAR System
Filing Detail
Form 10-K - Annual report [Section 13 and 15(d), not S-K Item 405]:
SEC Accession No. 0000320193-19-000119
Filing Date
2019-10-31
Accepted
2019-10-30 18:12:36
Documents
96
Period of Report
2019-09-28
Interactive Data

Document Format Files

Seq | Description | Document | Type | Size
--- | --- | --- | --- | ---
1 | 10-K | a10-k20199282019.htm iXBRL | 10-K | 2714096
2 | EXHIBIT 4.1 | a10-kexhibit412019.htm | EX-4.1 | 140694
3 | EXHIBIT 10.15 | a10-kexhibit10152019.htm | EX-10.15 | 50665
4 | EXHIBIT 10.16 | a10-kexhibit10162019.htm | EX-10.16 | 68558
5 | EXHIBIT 21.1 | a10-kexhibit2112019.htm | EX-21.1 | 10756
6 | EXHIBIT 23.1 | a10-kexhibit2312019.htm | EX-23.1 | 8071
7 | EXHIBIT 31.1 | a10-kexhibit3112019.htm | EX-31.1 | 15675
8 | EXHIBIT 31.2 | a10-kexhibit3122019.htm | EX-31.2 | 15711
9 | EXHIBIT 32.1 | a10-kexhibit3212019.htm | EX-32.1 | 15195
15 |  | chart-06f17b4ddd9352dc8dc.jpg | GRAPHIC | 79662
16 |  | g66145g66i38.jpg | GRAPHIC | 10963
| Complete submission text file | 0000320193-19-000119.txt |  | 12861616

Data Files

Seq | Description | Document | Type | Size
--- | --- | --- | --- | ---
10 | XBRL TAXONOMY EXTENSION SCHEMA DOCUMENT | aapl-20190928.xsd | EX-101.SCH | 56071
11 | XBRL TAXONOMY EXTENSION CALCULATION LINKBASE DOCUMENT | aapl-20190928_cal.xml | EX-101.CAL | 123668
12 | XBRL TAXONOMY EXTENSION DEFINITION LINKBASE DOCUMENT | aapl-20190928_def.xml | EX-101.DEF | 306363
13 | XBRL TAXONOMY EXTENSION LABEL LINKBASE DOCUMENT | aapl-20190928_lab.xml | EX-101.LAB | 878875
14 | XBRL TAXONOMY EXTENSION PRESENTATION LINKBASE DOCUMENT | aapl-20190928_pre.xml | EX-101.PRE | 520951
67 | EXTRACTED XBRL INSTANCE DOCUMENT | a10-k20199282019_htm.xml | XML | 2774010

Mailing Address ONE APPLE PARK WAY CUPERTINO CA 95014
Business Address ONE APPLE PARK WAY CUPERTINO CA 95014 (408) 996-1010
Apple Inc. (Filer) CIK: 0000320193 (see all company filings)

IRS No.: 942404110 | State of Incorp.: CA | Fiscal Year End: 0928
Type: 10-K | Act: 34 | File No.: 001-36743 | Film No.: 191181423
SIC: 3571 Electronic Computers
Office of Technology

EDGAR Search Results
Search the Next-Generation EDGAR System
EDGAR Search Results
Companies with names matching "PAPER"
Click on CIK to view company filings
Items 1 - 40

CIK | Company | State/Country
--- | --- | ---
0001599969 | Paper Battery Company, Inc. | NY
0001535514 | Paper Boy-AAT Ltd Liability Co | NY
0001503131 | Paper Boy-LSS, LLC. | NY
0001538157 | Paper Boy-Porgy, LLC | NY
0001523042 | Paper Boy-TAFT, LLC. | NY
0001290085 | Paper Chemicals, Inc. | TX
0001315771 | PAPER CO OF ATENQUIQUE, S.A. DE C.V. | O5
0001016900 | Applied Natural Gas Fuels, Inc. SIC: 1311 - CRUDE PETROLEUM & NATURAL GAS | CA
0001764266 | Paper Crane, LLC | NH
0001211188 | PAPER DOLL CO LLC | NY
0001447198 | PAPER MAN PRODUCTIONS LLC | CA
0001499900 | Paper Mill Village Lender, LLLP | GA
0001141407 | PAPER RECYLCING INC | GA
0001417469 | Paper Street Films LLC | ny
0000934509 | PAPER WAREHOUSE INC SIC: 5940 - RETAIL-MISCELLANEOUS SHOPPING GOODS STORES | MN
0001197130 | PAPER ZONE HOLDINGS LLC | WA
0001347802 | Papera Raymond J |
0001049190 | CASCADES PAPERBOARD INTERNATIONAL INC SIC: 2650 - PAPERBOARD CONTAINERS & BOXES | A8
0001576267 | PAPERBOARD PARENT, INC. | GA
0001392150 | Paperboy Ventures, LLC | DC
0000946112 | China Dongsheng International, Inc. SIC: 2834 - PHARMACEUTICAL PREPARATIONS | F4
0001415922 | PaperClip, Inc. SIC: 7372 - SERVICES-PREPACKAGED SOFTWARE | NJ
0001584965 | PAPERCO HOLDINGS II, L.P. | NY
0001584988 | PAPERCO INVESTMENTS, L.P. | NY
0001339104 | STARDOLL INC | X0
0001108514 | PAPEREXCHANGE COM INC SIC: 7389 - SERVICES-BUSINESS SERVICES, NEC | MA
0001171546 | PaperFree Medical Solutions, Inc. SIC: 7389 - SERVICES-BUSINESS SERVICES, NEC | IN
0001449758 | PAPERG, INC | CA
0001668091 | Paperiello Vincent C |
0001207637 | PAPERIN STEWART J |
0001477654 | Paperless Inc. | NY
0001730144 | Paperless Parts, Inc. | MA
0001468389 | Paperless Transaction Management, Inc. | MD
0001126443 | PAPERLINX LTD /FI | C3
0001445502 | PAPERLOVE LLC | CA
0001449649 | Papermaster Mark D |
0001106485 | PAPERMASTER STEVEN G | TX
0001157926 | PAPERNICK ALAN |
0001555356 | PaperShare, Inc. | WA
0001671312 | Paperspace Co. | NY

Company Information:

| Home | EDGAR Search Home | Latest Filings | Previous Page |

# No matching Ticker Symbol.

EDGAR Search Results
EDGAR Search Results
Mailing Address ONE APPLE PARK WAY CUPERTINO CA 95014
Business Address ONE APPLE PARK WAY CUPERTINO CA 95014 (408) 996-1010
Apple Inc. CIK#: 0000320193 (see all company filings)

SIC: 3571 - ELECTRONIC COMPUTERS
State location: CA | State of Inc.: CA | Fiscal Year End: 0926
formerly: APPLE COMPUTER INC (filings through 2007-01-04)
formerly: APPLE COMPUTER INC/ FA (filings through 1997-07-28)
formerly: APPLE INC (filings through 2019-08-05)
(Office of Technology)
Get insider transactions for this issuer.

Filter Results: | Filing Type: | Prior to: (YYYYMMDD) | Ownership? include exclude only | Limit Results Per Page |

Items 1 - 28 RSS Feed

Filings | Format | Description | Filing Date | File/Film Number
--- | --- | --- | --- | ---
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-19-000119 (34 Act) Size: 12 MB | 2019-10-31 | 001-36743 191181423
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-18-000145 (34 Act) Size: 12 MB | 2018-11-05 | 001-36743 181158788
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-17-000070 (34 Act) Size: 14 MB | 2017-11-03 | 001-36743 171174673
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001628280-16-020309 (34 Act) Size: 13 MB | 2016-10-26 | 001-36743 161953070
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-15-356351 (34 Act) Size: 9 MB | 2015-10-28 | 001-36743 151180619
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-14-383437 (34 Act) Size: 12 MB | 2014-10-27 | 000-10030 141175110
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-13-416534 (34 Act) Size: 11 MB | 2013-10-30 | 000-10030 131177575
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-12-444068 (34 Act) Size: 9 MB | 2012-10-31 | 000-10030 121171452
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-11-282113 (34 Act) Size: 9 MB | 2011-10-26 | 000-10030 111159350
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-10-238044 (34 Act) Size: 13 MB | 2010-10-27 | 000-10030 101145250
10-K/A | Documents Interactive Data | [Amend] Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-10-012091 (34 Act) Size: 5 MB | 2010-01-25 | 000-10030 10545024
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-09-214859 (34 Act) Size: 3 MB | 2009-10-27 | 000-10030 091139493
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001193125-08-224958 (34 Act) Size: 1 MB | 2008-11-05 | 000-10030 081162315
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-07-009340 (34 Act) Size: 1 MB | 2007-11-15 | 000-10030 071250316
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001104659-06-084288 (34 Act) Size: 4 MB | 2006-12-29 | 000-10030 061304002
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001104659-05-058421 (34 Act) Size: 3 MB | 2005-12-01 | 000-10030 051235812
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-04-035975 (34 Act) Size: 966 KB | 2004-12-03 | 000-10030 041181605
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-03-041604 Size: 2 MB | 2003-12-19 | 000-10030 031066037
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-02-007674 Size: 895 KB | 2002-12-19 | 000-10030 02863602
10-K405 | Documents | Annual report [Sections 13 and 15(d), S-K Item 405] Acc-no: 0000912057-01-544436 Size: 791 KB | 2001-12-21 | 000-10030 1821603
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000912057-00-053623 Size: 310 KB | 2000-12-14 | 000-10030 789406
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000912057-99-010244 Size: 502 KB | 1999-12-22 | 000-10030 99778628
10-K405 | Documents | Annual report [Sections 13 and 15(d), S-K Item 405] Acc-no: 0001047469-98-044981 Size: 341 KB | 1998-12-23 | 000-10030 98774868
10-K/A | Documents | [Amend] Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-98-001822 Size: 51 KB | 1998-01-23 | 000-10030 98511354
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0001047469-97-006960 Size: 639 KB | 1997-12-05 | 000-10030 97733413
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-96-000023 Size: 271 KB | 1996-12-19 | 000-10030 96683426
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-95-000016 Size: 232 KB | 1995-12-19 | 000-10030 95602696
10-K | Documents | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-94-000016 Size: 240 KB | 1994-12-13 | 000-10030 94564347

EDGAR Search Results
EDGAR Search Results
Mailing Address ONE APPLE PARK WAY CUPERTINO CA 95014
Business Address ONE APPLE PARK WAY CUPERTINO CA 95014 (408) 996-1010
Apple Inc. CIK#: 0000320193 (see all company filings)

SIC: 3571 - ELECTRONIC COMPUTERS
State location: CA | State of Inc.: CA | Fiscal Year End: 0926
formerly: APPLE COMPUTER INC (filings through 2007-01-04)
formerly: APPLE COMPUTER INC/ FA (filings through 1997-07-28)
formerly: APPLE INC (filings through 2019-08-05)
(Office of Technology)
Get insider transactions for this issuer.

Filter Results: | Filing Type: | Prior to: (YYYYMMDD) | Ownership? include exclude only | Limit Results Per Page |

Items 1 - 40 RSS Feed |

Filings | Format | Description | Filing Date | File/Film Number
--- | --- | --- | --- | ---
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-20-000010 (34 Act) Size: 9 MB | 2020-01-29 | 001-36743 20555794
8-K | Documents Interactive Data | Current report, items 2.02 and 9.01 Acc-no: 0000320193-20-000008 (34 Act) Size: 531 KB | 2020-01-28 | 001-36743 20554729
PX14A6G | Documents | Notice of exempt solicitation submitted by non-management Acc-no: 0001214659-20-000610 (34 Act) Size: 87 KB | 2020-01-27 | 001-36743 20548807
PX14A6G | Documents | Notice of exempt solicitation submitted by non-management Acc-no: 0001387131-20-000386 (34 Act) Size: 45 KB | 2020-01-22 | 001-36743 20537776
DEFA14A | Documents | Additional definitive proxy soliciting materials and Rule 14(a)(12) material Acc-no: 0001193125-20-001452 (34 Act) Size: 715 KB | 2020-01-03 | 001-36743 20506033
DEF 14A | Documents | Other definitive proxy statements Acc-no: 0001193125-20-001450 (34 Act) Size: 4 MB | 2020-01-03 | 001-36743 20505940
CERT | Documents | Acc-no: 0001354457-19-000604 (34 Act) Size: 202 KB | 2019-11-15 | 001-36743 191222519
8-A12B | Documents | Registration of securities [Section 12(b)] Acc-no: 0001193125-19-292825 (34 Act) Size: 19 KB | 2019-11-15 | 001-36743 191222426
8-K | Documents Interactive Data | Current report, items 8.01 and 9.01 Acc-no: 0001193125-19-292676 (34 Act) Size: 645 KB | 2019-11-15 | 001-36743 191222355
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-288412 (33 Act) Size: 439 KB | 2019-11-08 | 333-228159 191204489
FWP | Documents | Filing under Securities Act Rules 163/433 of free writing prospectuses Acc-no: 0001193125-19-287351 (34 Act) Size: 35 KB | 2019-11-07 | 333-228159 191200817
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-286514 (33 Act) Size: 433 KB | 2019-11-07 | 333-228159 191197982
S-8 POS | Documents | Securities to be offered to employees in employee benefit plans, post-effective amendments Acc-no: 0001193125-19-280516 (33 Act) Size: 74 KB | 2019-10-31 | 333-165214 191184102
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-19-000119 (34 Act) Size: 12 MB | 2019-10-31 | 001-36743 191181423
8-K | Documents Interactive Data | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000117 (34 Act) Size: 576 KB | 2019-10-30 | 001-36743 191180631
8-K | Documents Interactive Data | Current report, item 5.02 Acc-no: 0000320193-19-000093 (34 Act) Size: 295 KB | 2019-09-13 | 001-36743 191093220
8-K | Documents Interactive Data | Current report, items 8.01 and 9.01 Acc-no: 0001193125-19-242975 (34 Act) Size: 777 KB | 2019-09-11 | 001-36743 191088535
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-238922 (33 Act) Size: 390 KB | 2019-09-05 | 333-228159 191077641
FWP | Documents | Filing under Securities Act Rules 163/433 of free writing prospectuses Acc-no: 0001193125-19-237993 (34 Act) Size: 82 KB | 2019-09-05 | 333-228159 191075999
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-237090 (33 Act) Size: 375 KB | 2019-09-04 | 333-228159 191073320
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-19-000076 (34 Act) Size: 10 MB | 2019-07-31 | 001-36743 19989192
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000073 (34 Act) Size: 303 KB | 2019-07-30 | 001-36743 19985848
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-19-000066 (34 Act) Size: 10 MB | 2019-05-01 | 001-36743 19788072
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000063 (34 Act) Size: 289 KB | 2019-04-30 | 001-36743 19782221
CERT | Documents | Acc-no: 0001354457-19-000130 (34 Act) Size: 154 KB | 2019-03-14 | 001-36743 19681650
25 | Documents | Notification of the removal from listing and registration of matured, redeemed or retired securities Acc-no: 0001193125-19-074874 (34 Act) Size: 13 KB | 2019-03-14 | 001-36743 19681578
8-A12B | Documents | Registration of securities [Section 12(b)] Acc-no: 0001193125-19-074868 (34 Act) Size: 22 KB | 2019-03-14 | 001-36743 19681549
8-K | Documents | Current report, item 5.07 Acc-no: 0000320193-19-000032 (34 Act) Size: 66 KB | 2019-03-04 | 001-36743 19654221
SD | Documents | Acc-no: 0001193125-19-041571 (34 Act) Size: 585 KB | 2019-02-15 | 001-36743 19609779
SC 13G | Documents | Statement of acquisition of beneficial ownership by individuals Acc-no: 0001193125-19-041014 (34 Act) Size: 702 KB | 2019-02-14 | 005-33632 19607502
SC 13G/A | Documents | [Amend] Statement of acquisition of beneficial ownership by individuals Acc-no: 0000932471-19-004418 (34 Act) Size: 34 KB | 2019-02-11 | 005-33632 19582280
8-K | Documents | Current report, item 5.02 Acc-no: 0000320193-19-000026 (34 Act) Size: 29 KB | 2019-02-06 | 001-36743 19569878
PX14A6G | Documents | Notice of exempt solicitation submitted by non-management Acc-no: 0001214659-19-000797 (34 Act) Size: 10 KB | 2019-02-05 | 001-36743 19566496
SC 13G/A | Documents | [Amend] Statement of acquisition of beneficial ownership by individuals Acc-no: 0000215457-19-003343 (34 Act) Size: 13 KB | 2019-02-04 | 005-33632 19562213
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-19-000010 (34 Act) Size: 8 MB | 2019-01-30 | 001-36743 19552275
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000007 (34 Act) Size: 228 KB | 2019-01-29 | 001-36743 19549017
DEFA14A | Documents | Additional definitive proxy soliciting materials and Rule 14(a)(12) material Acc-no: 0001193125-19-004678 (34 Act) Size: 470 KB | 2019-01-08 | 001-36743 19516394
DEF 14A | Documents | Other definitive proxy statements Acc-no: 0001193125-19-004664 (34 Act) Size: 5 MB | 2019-01-08 | 001-36743 19516351
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000002 (34 Act) Size: 66 KB | 2019-01-02 | 001-36743 19502044
S-3ASR | Documents | Automatic shelf registration statement of securities of well-known seasoned issuers Acc-no: 0001193125-18-317844 (33 Act) Size: 768 KB | 2018-11-05 | 333-228159 181158810

EDGAR Filing Documents for 0000320193-19-000119
Search the Next-Generation EDGAR System
Filing Detail
Form 10-K - Annual report [Section 13 and 15(d), not S-K Item 405]:
SEC Accession No. 0000320193-19-000119
Filing Date
2019-10-31
Accepted
2019-10-30 18:12:36
Documents
96
Period of Report
2019-09-28
Interactive Data

Document Format Files

Seq | Description | Document | Type | Size
--- | --- | --- | --- | ---
1 | 10-K | a10-k20199282019.htm iXBRL | 10-K | 2714096
2 | EXHIBIT 4.1 | a10-kexhibit412019.htm | EX-4.1 | 140694
3 | EXHIBIT 10.15 | a10-kexhibit10152019.htm | EX-10.15 | 50665
4 | EXHIBIT 10.16 | a10-kexhibit10162019.htm | EX-10.16 | 68558
5 | EXHIBIT 21.1 | a10-kexhibit2112019.htm | EX-21.1 | 10756
6 | EXHIBIT 23.1 | a10-kexhibit2312019.htm | EX-23.1 | 8071
7 | EXHIBIT 31.1 | a10-kexhibit3112019.htm | EX-31.1 | 15675
8 | EXHIBIT 31.2 | a10-kexhibit3122019.htm | EX-31.2 | 15711
9 | EXHIBIT 32.1 | a10-kexhibit3212019.htm | EX-32.1 | 15195
15 |  | chart-06f17b4ddd9352dc8dc.jpg | GRAPHIC | 79662
16 |  | g66145g66i38.jpg | GRAPHIC | 10963
| Complete submission text file | 0000320193-19-000119.txt |  | 12861616

Data Files

Seq | Description | Document | Type | Size
--- | --- | --- | --- | ---
10 | XBRL TAXONOMY EXTENSION SCHEMA DOCUMENT | aapl-20190928.xsd | EX-101.SCH | 56071
11 | XBRL TAXONOMY EXTENSION CALCULATION LINKBASE DOCUMENT | aapl-20190928_cal.xml | EX-101.CAL | 123668
12 | XBRL TAXONOMY EXTENSION DEFINITION LINKBASE DOCUMENT | aapl-20190928_def.xml | EX-101.DEF | 306363
13 | XBRL TAXONOMY EXTENSION LABEL LINKBASE DOCUMENT | aapl-20190928_lab.xml | EX-101.LAB | 878875
14 | XBRL TAXONOMY EXTENSION PRESENTATION LINKBASE DOCUMENT | aapl-20190928_pre.xml | EX-101.PRE | 520951
67 | EXTRACTED XBRL INSTANCE DOCUMENT | a10-k20199282019_htm.xml | XML | 2774010

Mailing Address ONE APPLE PARK WAY CUPERTINO CA 95014
Business Address ONE APPLE PARK WAY CUPERTINO CA 95014 (408) 996-1010
Apple Inc. (Filer) CIK: 0000320193 (see all company filings)

IRS No.: 942404110 | State of Incorp.: CA | Fiscal Year End: 0928
Type: 10-K | Act: 34 | File No.: 001-36743 | Film No.: 191181423
SIC: 3571 Electronic Computers
Office of Technology